@@ -176,11 +176,15 @@ class delhi_hc_search:
             data.append(dat)
             soup = bs(current_page, 'html.parser')
             oj_details_elem = soup.find_all('button', {'class': 'button pull-right'})
-            self.oj_details = [
+            try:
+                self.oj_details = [
                 str(elem.get('onclick')).replace(str(elem.get('onclick'))[-1], '').replace('location.href=',
                                                                                            'http://delhihighcourt.nic.in/')
                 for elem in oj_details_elem]
 
+            except:
+                pass
+
             main_window = self.driver.current_window_handle
 
             # Order and Judgement link iteration happens here
@@ -267,35 +271,38 @@ class delhi_hc_search:
         li_even = soup.find_all('li', {"class": "clearfix even"})
         li = self.merge_alternate_list(li_odd, li_even)
         case_status_data = {}
-        for i in range(len(li)):
-            s0 = self.clean_text(li[i].select('span', attrs={'class': re.compile('^title*')})[0].get_text())
-            sr_no = s0.replace(".", "")
+        try:
+            for i in range(len(li)):
+                s0 = self.clean_text(li[i].select('span', attrs={'class': re.compile('^title*')})[0].get_text())
+                sr_no = s0.replace(".", "")
 
-            s1 = self.clean_text(li[i].select('span', attrs={'class': re.compile('^title*')})[1].get_text())
-            case_status1 = re.findall(r'\[.*?\]', s1)[0]
-            diary_no = s1.split(case_status1)[0].replace('\t', '')
+                s1 = self.clean_text(li[i].select('span', attrs={'class': re.compile('^title*')})[1].get_text())
+                case_status1 = re.findall(r'\[.*?\]', s1)[0]
+                diary_no = s1.split(case_status1)[0].replace('\t', '')
 
-            s2 = self.clean_text(li[i].select('span', attrs={'class': re.compile('^title*')})[2].get_text())
-            advocate = s2.split('Advocate :')[-1]
-            petitioner, respondent = s2.split('Advocate :')[0].split('Vs.')
+                s2 = self.clean_text(li[i].select('span', attrs={'class': re.compile('^title*')})[2].get_text())
+                advocate = s2.split('Advocate :')[-1]
+                petitioner, respondent = s2.split('Advocate :')[0].split('Vs.')
 
-            s3 = self.clean_text(li[i].select('span', attrs={'class': re.compile('^title*')})[3].get_text())
-            try:
-                court_no, case_status2, judgement_date = re.findall('^\D*(\d)\s(\D*)\s(\d+/\d+/\d+)', s3)[0]
-            except:
-                court_no, case_status2, judgement_date = "", "", ""
+                s3 = self.clean_text(li[i].select('span', attrs={'class': re.compile('^title*')})[3].get_text())
+                try:
+                    court_no, case_status2, judgement_date = re.findall('^\D*(\d)\s(\D*)\s(\d+/\d+/\d+)', s3)[0]
+                except:
+                    court_no, case_status2, judgement_date = "", "", ""
 
-            case_status_data[f'n_{i}'] = {}
-            case_status_data[f'n_{i}']['sr_no'] = sr_no
-            case_status_data[f'n_{i}']['diary_no'] = diary_no
-            case_status_data[f'n_{i}']['case_status1'] = case_status1
-            case_status_data[f'n_{i}']['petitioner'] = petitioner
-            case_status_data[f'n_{i}']['respondent'] = respondent
-            case_status_data[f'n_{i}']['advocate'] = advocate
-            case_status_data[f'n_{i}']['court_no'] = court_no
-            case_status_data[f'n_{i}']['case_status2'] = case_status2
-            case_status_data[f'n_{i}']['judgement_date'] = judgement_date
-        return case_status_data
+                case_status_data[f'n_{i}'] = {}
+                case_status_data[f'n_{i}']['sr_no'] = sr_no
+                case_status_data[f'n_{i}']['diary_no'] = diary_no
+                case_status_data[f'n_{i}']['case_status1'] = case_status1
+                case_status_data[f'n_{i}']['petitioner'] = petitioner
+                case_status_data[f'n_{i}']['respondent'] = respondent
+                case_status_data[f'n_{i}']['advocate'] = advocate
+                case_status_data[f'n_{i}']['court_no'] = court_no
+                case_status_data[f'n_{i}']['case_status2'] = case_status2
+                case_status_data[f'n_{i}']['judgement_date'] = judgement_date
+            return case_status_data
+        except:
+            return None
 
     def get_order_page_links(self, html):
         soup = bs(html, 'html.parser')
